<!-- markdownlint-disable MD007 -->
# BIDS

## Introduction

[**BIDS**](http://bids.neuroimaging.io/) (Brain Imaging Data Structure) is the standard adopted for the organisation
 of the datasets used by Clinica pipelines through the command line.
 BIDS provides a unified structure for organising and describing neuroimaging and behavioural data.
 The use of a standard like BIDS makes easier developing and distributing code that uses neuroimaging datasets.
 For this reason, when using Clinica pipelines from the command line, the input format of the dataset is required to be BIDS-compliant.

## An overview of the BIDS structure

Here is a general overview of the BIDS structure.
If you need more details, please check the [documentation](https://bids-specification.readthedocs.io/en/latest/) on the [website](http://bids.neuroimaging.io/).

```Text
BIDS_Dataset/
├── sub-CLNC01/
│   │   ├── ses-M00/
│   │   │   ├── anat/
│   │   │   │   ├── sub-CLNC01_ses-M00_T1w.json
│   │   │   │   └── sub-CLNC01_ses-M00_T1w.nii.gz
│   │   │   ├── dwi/
│   │   │   │   ├── sub-CLNC01_ses-M00_dwi.bval
│   │   │   │   ├── sub-CLNC01_ses-M00_dwi.bvec
│   │   │   │   ├── sub-CLNC01_ses-M00_dwi.json
│   │   │   │   ├── sub-CLNC01_ses-M00_dwi.nii.gz
│   │   │   │   └── ...
│   │   │   ├── fmap/
│   │   │   │   ├── sub-CLNC01_ses-M00_phasediff.json
│   │   │   │   ├── sub-CLNC01_ses-M00_phasediff.nii.gz
│   │   │   │   ├── sub-CLNC01_ses-M00_magnitude1.nii.gz
│   │   │   │   └── sub-CLNC01_ses-M00_magnitude2.nii.gz
│   │   │   ├── func/
│   │   │   │   ├── sub-CLNC01_ses-M00_task­-rest_bold.json
│   │   │   │   ├── sub-CLNC01_ses-M00_task­-rest_bold.nii.gz
│   │   │   │   └── ...
│   │   │   ├── pet/
│   │   │   │   ├── sub-CLNC01_ses-M00_trc-11CPIB_pet.json
│   │   │   │   ├── sub-CLNC01_ses-M00_trc-11CPIB_pet.nii.gz
│   │   │   │   ├── sub-CLNC01_ses-M00_trc-18FFDG_pet.json
│   │   │   │   ├── sub-CLNC01_ses-M00_trc-18FFDG_pet.nii.gz
│   │   │   └── sub-CLNC01_ses-M00_scans.tsv
│   │   ├── ses-M18/
│   │   │   └── ...
│   │   └── sub-CLNC01_sessions.tsv
├── sub-CLNC02/
│   └── ...
├── ...
└── participants.tsv
```

!!! note "PET modality"
    Clinica early adopted [BIDS Extension Proposal (BEP) 9](https://docs.google.com/document/d/1mqMLnxVdLwZjDd4ZiWFqjEAmOmfcModA_R535v3eQs0/edit) regarding PET modality before its official adoption in BIDS version 1.6.0.

    Since version 0.6, Clinica is now compliant with the official specifications for PET modality.
    This involves three main changes:

    - `task-rest` key/entity is now optional and ignored by Clinica
    - PET acquisitions with different tracers now use the new tracer entity `trc` instead of
    BIDS acquisition entity `acq`.
    - PET files must use tracer entity `trc` (optional in BIDS but necessary for Clinica pipelines) and
    label names follow the proposed convention in BIDS
    (pib -> 11CPIB, av45 -> 18FAV45, fbb -> 18FFBB, fdg -> 18FFDG, flute -> 18FFMM, tau -> 18FAV1451).

## Validation of BIDS datasets

[bids-validator](https://github.com/bids-standard/bids-validator) can be run to ensure that a dataset is BIDS-compliant.

Clinica provides tools to curate several publicly available neuroimaging datasets and convert them to BIDS. Datasets
currently supported are:

- [ADNI](../Converters/ADNI2BIDS/)
- [AIBL](../Converters/AIBL2BIDS/)
- [NIFD](../Converters/NIFD2BIDS/)
- [OASIS](../Converters/OASIS2BIDS/)
- [OASIS-3](../Converters/OASIS3TOBIDS/)

We decided to ignore several warnings and errors detected by the validator.
These are listed in the `.bids-validator-config.json` and `.bidsignore` files at the root of each BIDS folder.
These files are automatically generated by Clinica converters to ignore the following issues:

- Won't fix errors:
    - All participants do not have the same sessions or modalities (`MISSING_SESSION` / `INCONSISTENT_SUBJECTS`).
    - JSON files with column description are not generated as TSV files already explicit the purpose of the
    columns in metadata files (`CUSTOM_COLUMN_WITHOUT_DESCRIPTION`).
    - The optional field `authors` is not filled in `dataset_description.json` (`NO_AUTHORS`).
    - The folder `conversion_info` is not BIDS-compliant (`conversion_info/` in `.bidsignore`).
- fMRI-specific: these errors are not fixed as there are no preprocessing pipelines for this modality in Clinica yet
(`SLICE_TIMING_NOT_DEFINED` / `NIFTI_PIXDIM4` / `BOLD_NOT_4D` / `REPETITION_TIME_MUST_DEFINE` / `TASK_NAME_MUST_DEFINE`).
- Probable DICOM errors (`NIFTI_UNIT` / `INCONSISTENT_PARAMETERS`).
